==> ejc-bfyjerp-impl-3.0.0-20250430.045449-213-sources.jar: com/ejianc/business/oa/bean/MonInsuranceEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 月度保险明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_month_insurance")
public class MonInsuranceEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="human_type")
    private String humanType; // 人员类别
    @TableField(value="human_type_name")
    private String humanTypeName; // 人员类别
    @TableField(value="person_id")
    private Long personId; // 姓名
    @TableField(value="person_name")
    private String personName; // 姓名
    @TableField(value="dept_id")
    private Long deptId; // 部门
    @TableField(value="dept_name")
    private String deptName; // 部门
    @TableField(value="insured_type")
    private String insuredType; // 保险种类
    @TableField(value="insured_type_name")
    private String insuredTypeName; // 保险种类
    @TableField(value="fees_borne")
    private String feesBorne; // 费用承担情况
    @TableField(value="fees_borne_name")
    private String feesBorneName; // 费用承担情况
    @TableField(value="year")
    private String year; // 年份
    @TableField(value="month")
    private String month; // 月度
    @TableField(value="company_total_mny_month")
    private BigDecimal companyTotalMnyMonth; // 单位缴费金额
    @TableField(value="person_total_mny_month")
    private BigDecimal personTotalMnyMonth; // 个人缴费金额
    @TableField(value="total_mny_month")
    private BigDecimal totalMnyMonth; // 月费用合计
    @TableField(value="bill_date")
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date billDate; // 生成日期
    @TableField(value="up_down")
    private String upDown; // 当月增减情况0正常1:增2减
    @TableField(value="insurance_id")
    private Long insuranceId; // 保险缴纳申请单id

    public Long getInsuranceId() {
        return insuranceId;
    }

    public void setInsuranceId(Long insuranceId) {
        this.insuranceId = insuranceId;
    }

    public String getHumanType() {
        return humanType;
    }

    public void setHumanType(String humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public String getPersonName() {
        return personName;
    }

    public void setPersonName(String personName) {
        this.personName = personName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getInsuredType() {
        return insuredType;
    }

    public void setInsuredType(String insuredType) {
        this.insuredType = insuredType;
    }
    public String getInsuredTypeName() {
        return insuredTypeName;
    }

    public void setInsuredTypeName(String insuredTypeName) {
        this.insuredTypeName = insuredTypeName;
    }
    public String getFeesBorne() {
        return feesBorne;
    }

    public void setFeesBorne(String feesBorne) {
        this.feesBorne = feesBorne;
    }
    public String getFeesBorneName() {
        return feesBorneName;
    }

    public void setFeesBorneName(String feesBorneName) {
        this.feesBorneName = feesBorneName;
    }
    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }
    public String getMonth() {
        return month;
    }

    public void setMonth(String month) {
        this.month = month;
    }
    public BigDecimal getCompanyTotalMnyMonth() {
        return companyTotalMnyMonth;
    }

    public void setCompanyTotalMnyMonth(BigDecimal companyTotalMnyMonth) {
        this.companyTotalMnyMonth = companyTotalMnyMonth;
    }
    public BigDecimal getPersonTotalMnyMonth() {
        return personTotalMnyMonth;
    }

    public void setPersonTotalMnyMonth(BigDecimal personTotalMnyMonth) {
        this.personTotalMnyMonth = personTotalMnyMonth;
    }
    public BigDecimal getTotalMnyMonth() {
        return totalMnyMonth;
    }

    public void setTotalMnyMonth(BigDecimal totalMnyMonth) {
        this.totalMnyMonth = totalMnyMonth;
    }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public String getUpDown() {
        return upDown;
    }

    public void setUpDown(String upDown) {
        this.upDown = upDown;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250801.013036-262-sources.jar: com/ejianc/business/oa/bean/MonInsuranceEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 月度保险明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_month_insurance")
public class MonInsuranceEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="human_type")
    private String humanType; // 人员类别
    @TableField(value="human_type_name")
    private String humanTypeName; // 人员类别
    @TableField(value="person_id")
    private Long personId; // 姓名
    @TableField(value="person_name")
    private String personName; // 姓名
    @TableField(value="dept_id")
    private Long deptId; // 部门
    @TableField(value="dept_name")
    private String deptName; // 部门
    @TableField(value="insured_type")
    private String insuredType; // 保险种类
    @TableField(value="insured_type_name")
    private String insuredTypeName; // 保险种类
    @TableField(value="fees_borne")
    private String feesBorne; // 费用承担情况
    @TableField(value="fees_borne_name")
    private String feesBorneName; // 费用承担情况
    @TableField(value="year")
    private String year; // 年份
    @TableField(value="month")
    private String month; // 月度
    @TableField(value="company_total_mny_month")
    private BigDecimal companyTotalMnyMonth; // 单位缴费金额
    @TableField(value="person_total_mny_month")
    private BigDecimal personTotalMnyMonth; // 个人缴费金额
    @TableField(value="total_mny_month")
    private BigDecimal totalMnyMonth; // 月费用合计
    @TableField(value="bill_date")
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date billDate; // 生成日期
    @TableField(value="up_down")
    private String upDown; // 当月增减情况0正常1:增2减
    @TableField(value="insurance_id")
    private Long insuranceId; // 保险缴纳申请单id
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getInsuranceId() {
        return insuranceId;
    }

    public void setInsuranceId(Long insuranceId) {
        this.insuranceId = insuranceId;
    }

    public String getHumanType() {
        return humanType;
    }

    public void setHumanType(String humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public String getPersonName() {
        return personName;
    }

    public void setPersonName(String personName) {
        this.personName = personName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getInsuredType() {
        return insuredType;
    }

    public void setInsuredType(String insuredType) {
        this.insuredType = insuredType;
    }
    public String getInsuredTypeName() {
        return insuredTypeName;
    }

    public void setInsuredTypeName(String insuredTypeName) {
        this.insuredTypeName = insuredTypeName;
    }
    public String getFeesBorne() {
        return feesBorne;
    }

    public void setFeesBorne(String feesBorne) {
        this.feesBorne = feesBorne;
    }
    public String getFeesBorneName() {
        return feesBorneName;
    }

    public void setFeesBorneName(String feesBorneName) {
        this.feesBorneName = feesBorneName;
    }
    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }
    public String getMonth() {
        return month;
    }

    public void setMonth(String month) {
        this.month = month;
    }
    public BigDecimal getCompanyTotalMnyMonth() {
        return companyTotalMnyMonth;
    }

    public void setCompanyTotalMnyMonth(BigDecimal companyTotalMnyMonth) {
        this.companyTotalMnyMonth = companyTotalMnyMonth;
    }
    public BigDecimal getPersonTotalMnyMonth() {
        return personTotalMnyMonth;
    }

    public void setPersonTotalMnyMonth(BigDecimal personTotalMnyMonth) {
        this.personTotalMnyMonth = personTotalMnyMonth;
    }
    public BigDecimal getTotalMnyMonth() {
        return totalMnyMonth;
    }

    public void setTotalMnyMonth(BigDecimal totalMnyMonth) {
        this.totalMnyMonth = totalMnyMonth;
    }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public String getUpDown() {
        return upDown;
    }

    public void setUpDown(String upDown) {
        this.upDown = upDown;
    }
    
}
